# rahul_pattern

## A simple python package for pattern printing

---

# Use the package in your project

### Install the package

```
pip install rahul_pattern
```

### Using the package

```
import rahul_pattern.pattern as pattern

pattern.pattern_triangle(5)
```

---

Rahul Pain © 2023

> **Note**
> This is for a university project. Might not be maintained in future.
